# utils.py

########################################################################
#  SdiQt -- SDictionary viewer based on Qt library
#  Copyright (C) 2006 Dmitri Brechalov
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  The full license is in the file COPYING, distributed as part of
#  this software.
########################################################################

def getProgramPath():
    import sys
    import os.path
    pname = sys.argv[0]
    if os.path.islink(pname):
        pname = os.readlink(pname)
    return os.path.split(pname)[0]

def openConfig(fname, mode):
    '''Return config file object'''
    import os.path
    return open(os.path.expanduser(fname), mode)

_useQtopia = False

def setQtopia(flag):
    global _useQtopia
    _useQtopia = flag

def isQtopia():
    return _useQtopia

def appendHistory(history, combo, fname, txt):
    from qt import QString
    history[txt] = fname
    combo.clear()
    i = 0
    for item in history.keys():
        combo.insertItem(QString().fromUtf8(item))
        if item == txt:
            combo.setCurrentItem(i)
        i += 1
    
class SimpleConfig:
    def __init__(self, fileName):
        self.data = {}
        self.fileName = fileName
        self.__readData()

    def __readData(self):
        self.data = {}
        try:
            f = openConfig(self.fileName, 'r')
        except:
            return
        for line in f.readlines():
            line = line.strip()
            if not line or line.startswith('#'):
                continue     # just empty line or comment
            try:
                (key, value) = line.split('=', 1)
                self.data[key] = value
            except:
                pass
        f.close()

    def save(self):
        f = openConfig(self.fileName, 'w')
        for (k, v) in self.data.items():
            f.write('%s=%s\n' % (k, v))
        f.close()

    def close(self):
        self.save()

    def readStr(self, key, default=None):
        try:
            value = self.data[key]
        except:
            value = default
        return value

    def readInt(self, key, default=None):
        try:
            return int(self.readStr(key))
        except:
            return default

    def readBool(self, key, default=False):
        try:
            return bool(self.readInt(key))
        except:
            return default

    def keys(self, start=None):
        if start:
            result = [ item for item in self.data.keys() \
                       if item.startswith(start) ]
        else:
            result = self.keys()
        return result

    def values(self, start=None):
        keys = self.keys(start)
        result = [ self.data[k] for k in keys ]
        return result

    def writeStr(self, key, value):
        self.data[key] = str(value)
        
    writeInt = writeStr
        
    def writeBool(self, key, value):
        self.writeStr(key, int(value))

# end of utils.py
